@@ -7,6 +7,7 @@
 #include <QApplication>
 #include <QPointer>
 #include <QProcess>
+#include <QQuickStyle>
 #include <QThread>
 
 #ifdef Q_OS_WIN
@@ -49,6 +50,10 @@ int main(int argc, char **argv)
     QIcon::setFallbackThemeName(QStringLiteral("breeze"));
 
     QApplication app(argc, argv);
+
+    IndicatorHelper helper;
+    helper.startDaemon();
+
     KAboutData about(QStringLiteral("kdeconnect-indicator"),
                      i18n("KDE Connect Indicator"),
                      QStringLiteral(KDECONNECT_VERSION_STRING),
@@ -60,20 +65,13 @@ int main(int argc, char **argv)
     KCrash::initialize();
 
 #ifdef Q_OS_WIN
-    KColorSchemeManager manager;
+    KColorSchemeManager::instance();
     QApplication::setStyle(QStringLiteral("breeze"));
-    IndicatorHelper helper(QUrl::fromLocalFile(qApp->applicationDirPath()));
-#else
-    IndicatorHelper helper;
 #endif
 
-    helper.preInit();
-
-    // Run Daemon initialization step
-    // When run from macOS app bundle, D-Bus call should be later than kdeconnectd and D-Bus daemon
-    QProcess kdeconnectd;
-    if (helper.daemonHook(kdeconnectd)) {
-        return -1;
+    // Default to org.kde.desktop style unless the user forces another style
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 
     KDBusService dbusService(KDBusService::Unique);
@@ -130,7 +128,6 @@ int main(int argc, char **argv)
         }
         // Add quit menu
 #if defined Q_OS_MAC
-
         menu->addAction(i18n("Quit"), []() {
             auto message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect.daemon"),
                                                           QStringLiteral("/MainApplication"),
@@ -194,8 +191,5 @@ int main(int argc, char **argv)
 
     app.setQuitOnLastWindowClosed(false);
 
-    // Finish init
-    helper.postInit();
-
     return app.exec();
 }
