@@ -4,31 +4,21 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef SHARE_CONFIG_H
-#define SHARE_CONFIG_H
+#pragma once
 
 #include "kcmplugin/kdeconnectpluginkcm.h"
+#include "ui_share_config.h"
 
-namespace Ui {
-    class ShareConfigUi;
-}
-
-class ShareConfig
-    : public KdeConnectPluginKcm
+class ShareConfig : public KdeConnectPluginKcm
 {
     Q_OBJECT
 public:
-    ShareConfig(QWidget* parent, const QVariantList&);
-    ~ShareConfig() override;
+    ShareConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
 
-public Q_SLOTS:
     void save() override;
     void load() override;
     void defaults() override;
 
 private:
-    Ui::ShareConfigUi* m_ui;
-
+    Ui::ShareConfigUi m_ui;
 };
-
-#endif
