@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef SHAREPLUGIN_H
-#define SHAREPLUGIN_H
+#pragma once
 
 #include <QPointer>
 
@@ -35,10 +34,7 @@ public:
         shareUrl(QUrl(file), true);
     }
 
-    bool receivePacket(const NetworkPacket &np) override;
-    void connected() override
-    {
-    }
+    void receivePacket(const NetworkPacket &np) override;
     QString dbusPath() const override;
 
 private Q_SLOTS:
@@ -57,4 +53,3 @@ private:
 
     QPointer<CompositeFileTransferJob> m_compositeJob;
 };
-#endif
